@@ -1,7 +1,7 @@
-/* 
+/*
  * definitions for dc's "register" declarations
  *
- * Copyright (C) 1994 Free Software Foundation, Inc.
+ * Copyright (C) 1994, 2000 Free Software Foundation, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,22 +18,21 @@
  * program's author (see below) or write to:
  *
  *    The Free Software Foundation, Inc.
- *    59 Temple Place, Suite 330
- *    Boston, MA 02111 USA
+ *    51 Franklin Street, Fifth Floor
+ *    Boston, MA 02110-1301  USA
  */
 
 #ifdef HAVE_LIMITS_H
 # include <limits.h>	/* UCHAR_MAX */
 #endif
+#ifndef UCHAR_MAX
+# define UCHAR_MAX ((unsigned char)~0)
+#endif
 
 /* determine how many register stacks there are */
 #ifndef DC_REGCOUNT
-# ifndef UCHAR_MAX
-#  define DC_REGCOUNT 256
-# else
-#  define DC_REGCOUNT (UCHAR_MAX+1)
-# endif
-#endif /* not DC_REGCOUNT */
+# define DC_REGCOUNT (UCHAR_MAX+1)
+#endif
 
 /* efficiency hack for masking arbritrary integers to 0..(DC_REGCOUNT-1) */
 #if (DC_REGCOUNT & (DC_REGCOUNT-1)) == 0	/* DC_REGCOUNT is power of 2 */
